﻿using System.Diagnostics;
using System.Drawing;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinEditors;
using System;
using System.Windows.Forms;

namespace UltraGridBUPrototype
{
    public class CreatingUiElement : IUIElementCreationFilter
    {
        public static UltraGrid grid;
        public void AfterCreateChildElements(UIElement parent)
        {
            var el = parent as HeaderUIElement;

            if (el != null)
            {
                var newButton = new ButtonUIElement(el)
                {
                    Text = "X",
                    Rect = new Rectangle(el.Rect.X + el.Rect.Width - 20, el.Rect.Y, 18, 18)
                };

                el.ChildElements.Add(newButton);
                newButton.ElementClick += NewButtonElementClick;
            }

            DependentTextUIElement Del = parent as DependentTextUIElement;

            if (Del != null && Del.Text.Length < 4)
            {

                UltraTextEditor ed = new UltraTextEditor();
                ed.Parent = Del.Control;
                ed.BorderStyle = UIElementBorderStyle.None;
                ed.DisplayStyle = EmbeddableElementDisplayStyle.Office2010;
                ed.Location = new Point(Del.Rect.X + 80, Del.Rect.Y);
                ed.Width = 75;
                ed.AfterExitEditMode += new System.EventHandler(ed_AfterExitEditMode);
            }


            foreach (Control cnt in grid.Controls)
            {
                DependentTextUIElement UI = grid.DisplayLayout.UIElement.ElementFromPoint(cnt.Location) as DependentTextUIElement;
                if (cnt.GetType() == typeof(UltraTextEditor) && UI == null)// && !IsScrol)
                {
                    grid.Controls.Remove(cnt);
                }
            }
        }

        void ed_AfterExitEditMode(object sender, System.EventArgs e)
        {
            UltraTextEditor editor = sender as UltraTextEditor;
            if (editor == null || editor.Text == "" || editor.Value == null) return;

            foreach (UltraGridRow it in grid.Rows)
            {
                DependentTextUIElement UI = grid.DisplayLayout.UIElement.ElementFromPoint(editor.Location) as DependentTextUIElement;
                foreach (UltraGridRow rr in it.ChildBands[0].Rows.All)
                {
                    if (rr.IsGroupByRow && rr.Description == UI.Text)
                    {
                        foreach (UltraGridRow row in it.ChildBands[0].Rows[rr.Index].ChildBands[0].Rows.All)
                        {
                            row.Cells[3].Value = Convert.ToInt32(row.Cells[3].Value) * Convert.ToInt32(editor.Text);
                        }
                    }
                }
            }
        }


        static void NewButtonElementClick(object sender, UIElementEventArgs e)
        {
            var buttonUiElement = e.Element as ButtonUIElement;

            var headerUiElement = buttonUiElement.Parent as HeaderUIElement;

            var bandHeadersUiElement = headerUiElement.Parent as BandHeadersUIElement;

            var rowColRegionIntersectionUiElement = bandHeadersUiElement.Parent as RowColRegionIntersectionUIElement;

            foreach (var v in rowColRegionIntersectionUiElement.ChildElements)
            {
                if (v is RowUIElement)
                {
                    var rowUiElement = v as RowUIElement;


                    Debug.WriteLine("RowUIElement: " + rowUiElement);
                    Debug.WriteLine("Row: " + rowUiElement.Row);
                    Debug.WriteLine("ListObject: " + rowUiElement.Row.ListObject);
                }
            }

            var dataAreaUiElement = rowColRegionIntersectionUiElement.Parent as DataAreaUIElement;
            var ultraGridUiElement = dataAreaUiElement.Parent as UltraGridUIElement;

            Debug.WriteLine(ultraGridUiElement.ToString());
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}